#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-equality
version:              1.0.1
visibility:           public
id:                   type-equality-1.0.1-Hps6Hfpg2Do50r4l4m5dLc
key:                  type-equality-1.0.1-Hps6Hfpg2Do50r4l4m5dLc
license:              BSD-3-Clause
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>

author:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>, Martijn van Steenbergen

stability:            provisional
homepage:             https://github.com/hesselink/type-equality
synopsis:             Data.Type.Equality compat package
description:
    This library defines a propositional equality data type,
    shims @Data.Type.Equality@ as well as possible for older GHCs (< 7.8).

    @
    data a :~: b where
    \    Refl :: a :~: a
    @

    The module @Data.Type.Equality.Hetero@ shims @:~~:@ equality, for
    compilers with @PolyKinds@

category:             Data, Dependent Types
abi:                  642d53bf266ac4754f83e5fdb2e6a055
exposed:              True
exposed-modules:      Data.Type.Equality.Hetero
import-dirs:          /usr/lib/ghc-9.6.6/site-local/type-equality-1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/type-equality-1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/type-equality-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-equality
hs-libraries:         HStype-equality-1.0.1-Hps6Hfpg2Do50r4l4m5dLc
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-type-equality/html/type-equality.haddock

haddock-html:         /usr/share/doc/haskell-type-equality/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

